Index: net/socket/ssl_client_socket_nss.h |
diff --git a/net/socket/ssl_client_socket_nss.h b/net/socket/ssl_client_socket_nss.h |
index db567c477d54ef88aac1edb20ccbca31d30f7074..8518084cbb82199b16ff593a05e24cb14d6c23d8 100644 |
--- a/net/socket/ssl_client_socket_nss.h |
+++ b/net/socket/ssl_client_socket_nss.h |
@@ -30,6 +30,7 @@ namespace net { |
class BoundNetLog; |
class CertVerifier; |
class ClientSocketHandle; |
+class SSLHostInfo; |
class X509Certificate; |
// An SSL client socket implemented with Mozilla NSS. |
@@ -41,7 +42,8 @@ class SSLClientSocketNSS : public SSLClientSocket { |
// settings. |
SSLClientSocketNSS(ClientSocketHandle* transport_socket, |
const std::string& hostname, |
- const SSLConfig& ssl_config); |
+ const SSLConfig& ssl_config, |
+ SSLHostInfo* ssl_host_info); |
~SSLClientSocketNSS(); |
// SSLClientSocket methods: |
@@ -213,12 +215,14 @@ class SSLClientSocketNSS : public SSLClientSocket { |
// When performing Snap Start we need to predict the NPN protocol which the |
// server is going to speak before we actually perform the handshake. Thus |
// the last NPN protocol used is serialised in |ssl_config.ssl_host_info| |
// and kept in these fields: |
SSLClientSocket::NextProtoStatus predicted_npn_status_; |
std::string predicted_npn_proto_; |
bool predicted_npn_proto_used_; |
+ scoped_ptr<SSLHostInfo> ssl_host_info_; |
+ |
#if defined(OS_WIN) |
// A CryptoAPI in-memory certificate store. We use it for two purposes: |
// 1. Import server certificates into this store so that we can verify and |
@@ -213,12 +215,14 @@ class SSLClientSocketNSS : public SSLClientSocket { |
// When performing Snap Start we need to predict the NPN protocol which the |
// server is going to speak before we actually perform the handshake. Thus |
- // the last NPN protocol used is serialised in |ssl_config.ssl_host_info| |
+ // the last NPN protocol used is serialised in |ssl_host_info_| |
// and kept in these fields: |
SSLClientSocket::NextProtoStatus predicted_npn_status_; |